#######################
# Onion Skinning GUI
#######################
import bpy
from .ops import *


''' GUI '''


class ANMX_gui(bpy.types.Panel):
    """Panel for all MotionFX Operations"""
    bl_idname = 'VIEW3D_PT_animextras_panel'
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'AnimExtras'
    bl_label = 'Onion Skinning'

    def draw(self, context):
        layout = self.layout
        access = context.scene.anmx_data
        obj = context.object

        if len(context.scene.anmx_coll.ob_coll) < 1:
            layout.operator("anim_extras.set_onions")
            return
        else:
            row = layout.row(align=True)
            row.operator("anim_extras.update_onions", text="Update All")
            row.operator("anim_extras.add_onions", text="Add Selected")
            row = layout.row(align=True)
            row.operator("anim_extras.clear_all", text="Clear All")
            row.operator("anim_extras.clear_onions", text="Clear Selected")

        col = layout.column()
        col.prop(access, "onion_mode")

        col.separator(factor=1)

        row = layout.row()

        row = row.split(factor=0.3)

        row.label(text="Amount:")
        row.prop(access, "skin_count", text="")

        if access.onion_mode == "PFS":
            row = layout.row()

            row = row.split(factor=0.3)

            row.label(text="Step:")
            row.prop(access, "skin_step", text="")

        row = layout.row(align=True)

        text = "Past"
        if access.onion_mode == "INB":
            text = "Inbetween Color"

        box = row.box()
        col = box.column(align=True)
        col.label(text=text)
        col.prop(access, "past_color", text="")
        col.prop(access, "past_opacity_start",
                 text="Start Opacity", slider=True)
        col.prop(access, "past_opacity_end", text="End Opacity", slider=True)
        col.prop(access, "past_enabled")

        text = "Future"

        if access.onion_mode == "INB":
            text = "Direct Keying Color"

        box = row.box()
        col = box.column(align=True)
        col.label(text=text)
        col.prop(access, "future_color", text="")
        col.prop(access, "future_opacity_start",
                 text="Start Opacity", slider=True)
        col.prop(access, "future_opacity_end", text="End Opacity", slider=True)
        col.prop(access, "future_enabled")

        layout.separator(factor=1)

        layout.prop(access, "use_xray")
        layout.prop(access, "use_flat")

        layout.separator(factor=1)

        text = "Draw"
        if access.toggle:
            text = "Stop Drawing"
        layout.prop(access, "toggle", text=text, toggle=True)
